==> mappingservice.api-1.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/lfm/mappingservice/rev150906/mapping/changed/SubscriberItem.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.mapping.changed;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.MappingChanged;
import org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.lisp.proto.rev151105.SubscriberDataGrouping;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * The list of subscribers to be notified of this change.
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>odl-mappingservice</b>
 * <pre>
 * list subscriber-item {
 *     container subscriber-data {
 *         leaf ttl {
 *             type int32;
 *         }
 *         container rloc {
 *             leaf address-type {
 *                 type lisp-address-family-ref;
 *             }
 *             leaf virtual-network-id {
 *                 type instance-id-type;
 *             }
 *             choice address {
 *                 case afi-list {
 *                     container afi-list {
 *                         leaf-list address-list {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case application-data {
 *                     container application-data {
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                         leaf protocol {
 *                             type uint8;
 *                         }
 *                         leaf ip-tos {
 *                             type int32;
 *                         }
 *                         leaf local-port-low {
 *                             type port-number;
 *                         }
 *                         leaf local-port-high {
 *                             type port-number;
 *                         }
 *                         leaf remote-port-low {
 *                             type port-number;
 *                         }
 *                         leaf remote-port-high {
 *                             type port-number;
 *                         }
 *                     }
 *                 }
 *                 case as-number {
 *                     leaf as-number {
 *                         type as-number;
 *                     }
 *                 }
 *                 case as-number-lcaf {
 *                     container as-number-lcaf {
 *                         leaf as {
 *                             type as-number;
 *                         }
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case distinguished-name {
 *                     leaf distinguished-name {
 *                         type distinguished-name-type;
 *                     }
 *                 }
 *                 case explicit-locator-path {
 *                     container explicit-locator-path {
 *                         list hop {
 *                             key "hop-id";
 *                             leaf hop-id {
 *                                 type string;
 *                             }
 *                             leaf address {
 *                                 type simple-address;
 *                             }
 *                             leaf lrs-bits {
 *                                 type bits;
 *                             }
 *                         }
 *                     }
 *                 }
 *                 case geo-coordinates {
 *                     container geo-coordinates {
 *                         leaf latitude {
 *                             type bits;
 *                         }
 *                         leaf latitude-degrees {
 *                             type uint8;
 *                         }
 *                         leaf latitude-minutes {
 *                             type uint8;
 *                         }
 *                         leaf latitude-seconds {
 *                             type uint8;
 *                         }
 *                         leaf longitude {
 *                             type bits;
 *                         }
 *                         leaf longitude-degrees {
 *                             type uint16;
 *                         }
 *                         leaf longitude-minutes {
 *                             type uint8;
 *                         }
 *                         leaf longitude-seconds {
 *                             type uint8;
 *                         }
 *                         leaf altitude {
 *                             type int32;
 *                         }
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case instance-id {
 *                     container instance-id {
 *                         leaf iid {
 *                             type instance-id-type;
 *                         }
 *                         leaf mask-length {
 *                             type uint8;
 *                         }
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case ipv4 {
 *                     leaf ipv4 {
 *                         type ipv4-address;
 *                     }
 *                 }
 *                 case ipv4-binary {
 *                     leaf ipv4-binary {
 *                         type ipv4-address-binary;
 *                     }
 *                 }
 *                 case ipv4-prefix {
 *                     leaf ipv4-prefix {
 *                         type ipv4-prefix;
 *                     }
 *                 }
 *                 case ipv4-prefix-binary {
 *                     leaf ipv4-address-binary {
 *                         type ipv4-address-binary;
 *                     }
 *                     leaf ipv4-mask-length {
 *                         type uint8;
 *                     }
 *                 }
 *                 case ipv6 {
 *                     leaf ipv6 {
 *                         type ipv6-address;
 *                     }
 *                 }
 *                 case ipv6-binary {
 *                     leaf ipv6-binary {
 *                         type ipv6-address-binary;
 *                     }
 *                 }
 *                 case ipv6-prefix {
 *                     leaf ipv6-prefix {
 *                         type ipv6-prefix;
 *                     }
 *                 }
 *                 case ipv6-prefix-binary {
 *                     leaf ipv6-address-binary {
 *                         type ipv6-address-binary;
 *                     }
 *                     leaf ipv6-mask-length {
 *                         type uint8;
 *                     }
 *                 }
 *                 case key-value-address {
 *                     container key-value-address {
 *                         leaf key {
 *                             type simple-address;
 *                         }
 *                         leaf value {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case mac {
 *                     leaf mac {
 *                         type mac-address;
 *                     }
 *                 }
 *                 case nat-traversal {
 *                     container nat-traversal {
 *                         leaf ms-udp-port {
 *                             type uint16;
 *                         }
 *                         leaf etr-udp-port {
 *                             type uint16;
 *                         }
 *                         leaf global-etr-rloc {
 *                             type simple-address;
 *                         }
 *                         leaf ms-rloc {
 *                             type simple-address;
 *                         }
 *                         leaf private-etr-rloc {
 *                             type simple-address;
 *                         }
 *                         leaf-list rtr-rlocs {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case no-address {
 *                     leaf no-address {
 *                         type empty;
 *                     }
 *                 }
 *                 case null-address {
 *                     container null-address {
 *                         leaf address {
 *                             type empty;
 *                         }
 *                     }
 *                 }
 *                 case service-path {
 *                     container service-path {
 *                         leaf service-path-id {
 *                             type service-path-id-type;
 *                         }
 *                         leaf service-index {
 *                             type uint8;
 *                         }
 *                     }
 *                 }
 *                 case source-dest-key {
 *                     container source-dest-key {
 *                         leaf source {
 *                             type simple-address;
 *                         }
 *                         leaf dest {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *             }
 *             uses augmented-lisp-address;
 *         }
 *         container eid {
 *             leaf address-type {
 *                 type lisp-address-family-ref;
 *             }
 *             leaf virtual-network-id {
 *                 type instance-id-type;
 *             }
 *             choice address {
 *                 case afi-list {
 *                     container afi-list {
 *                         leaf-list address-list {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case application-data {
 *                     container application-data {
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                         leaf protocol {
 *                             type uint8;
 *                         }
 *                         leaf ip-tos {
 *                             type int32;
 *                         }
 *                         leaf local-port-low {
 *                             type port-number;
 *                         }
 *                         leaf local-port-high {
 *                             type port-number;
 *                         }
 *                         leaf remote-port-low {
 *                             type port-number;
 *                         }
 *                         leaf remote-port-high {
 *                             type port-number;
 *                         }
 *                     }
 *                 }
 *                 case as-number {
 *                     leaf as-number {
 *                         type as-number;
 *                     }
 *                 }
 *                 case as-number-lcaf {
 *                     container as-number-lcaf {
 *                         leaf as {
 *                             type as-number;
 *                         }
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case distinguished-name {
 *                     leaf distinguished-name {
 *                         type distinguished-name-type;
 *                     }
 *                 }
 *                 case explicit-locator-path {
 *                     container explicit-locator-path {
 *                         list hop {
 *                             key "hop-id";
 *                             leaf hop-id {
 *                                 type string;
 *                             }
 *                             leaf address {
 *                                 type simple-address;
 *                             }
 *                             leaf lrs-bits {
 *                                 type bits;
 *                             }
 *                         }
 *                     }
 *                 }
 *                 case geo-coordinates {
 *                     container geo-coordinates {
 *                         leaf latitude {
 *                             type bits;
 *                         }
 *                         leaf latitude-degrees {
 *                             type uint8;
 *                         }
 *                         leaf latitude-minutes {
 *                             type uint8;
 *                         }
 *                         leaf latitude-seconds {
 *                             type uint8;
 *                         }
 *                         leaf longitude {
 *                             type bits;
 *                         }
 *                         leaf longitude-degrees {
 *                             type uint16;
 *                         }
 *                         leaf longitude-minutes {
 *                             type uint8;
 *                         }
 *                         leaf longitude-seconds {
 *                             type uint8;
 *                         }
 *                         leaf altitude {
 *                             type int32;
 *                         }
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case instance-id {
 *                     container instance-id {
 *                         leaf iid {
 *                             type instance-id-type;
 *                         }
 *                         leaf mask-length {
 *                             type uint8;
 *                         }
 *                         leaf address {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case ipv4 {
 *                     leaf ipv4 {
 *                         type ipv4-address;
 *                     }
 *                 }
 *                 case ipv4-binary {
 *                     leaf ipv4-binary {
 *                         type ipv4-address-binary;
 *                     }
 *                 }
 *                 case ipv4-prefix {
 *                     leaf ipv4-prefix {
 *                         type ipv4-prefix;
 *                     }
 *                 }
 *                 case ipv4-prefix-binary {
 *                     leaf ipv4-address-binary {
 *                         type ipv4-address-binary;
 *                     }
 *                     leaf ipv4-mask-length {
 *                         type uint8;
 *                     }
 *                 }
 *                 case ipv6 {
 *                     leaf ipv6 {
 *                         type ipv6-address;
 *                     }
 *                 }
 *                 case ipv6-binary {
 *                     leaf ipv6-binary {
 *                         type ipv6-address-binary;
 *                     }
 *                 }
 *                 case ipv6-prefix {
 *                     leaf ipv6-prefix {
 *                         type ipv6-prefix;
 *                     }
 *                 }
 *                 case ipv6-prefix-binary {
 *                     leaf ipv6-address-binary {
 *                         type ipv6-address-binary;
 *                     }
 *                     leaf ipv6-mask-length {
 *                         type uint8;
 *                     }
 *                 }
 *                 case key-value-address {
 *                     container key-value-address {
 *                         leaf key {
 *                             type simple-address;
 *                         }
 *                         leaf value {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case mac {
 *                     leaf mac {
 *                         type mac-address;
 *                     }
 *                 }
 *                 case nat-traversal {
 *                     container nat-traversal {
 *                         leaf ms-udp-port {
 *                             type uint16;
 *                         }
 *                         leaf etr-udp-port {
 *                             type uint16;
 *                         }
 *                         leaf global-etr-rloc {
 *                             type simple-address;
 *                         }
 *                         leaf ms-rloc {
 *                             type simple-address;
 *                         }
 *                         leaf private-etr-rloc {
 *                             type simple-address;
 *                         }
 *                         leaf-list rtr-rlocs {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *                 case no-address {
 *                     leaf no-address {
 *                         type empty;
 *                     }
 *                 }
 *                 case null-address {
 *                     container null-address {
 *                         leaf address {
 *                             type empty;
 *                         }
 *                     }
 *                 }
 *                 case service-path {
 *                     container service-path {
 *                         leaf service-path-id {
 *                             type service-path-id-type;
 *                         }
 *                         leaf service-index {
 *                             type uint8;
 *                         }
 *                     }
 *                 }
 *                 case source-dest-key {
 *                     container source-dest-key {
 *                         leaf source {
 *                             type simple-address;
 *                         }
 *                         leaf dest {
 *                             type simple-address;
 *                         }
 *                     }
 *                 }
 *             }
 *             uses augmented-lisp-address;
 *         }
 *         uses rloc-container;
 *         uses eid-container;
 *     }
 *     uses subscriber-data-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>odl-mappingservice/mapping-changed/subscriber-item</i>
 *
 * <p>To create instances of this class use {@link SubscriberItemBuilder}.
 * @see SubscriberItemBuilder
 *
 *
 */
public interface SubscriberItem
    extends
    ChildOf<MappingChanged>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.mapping.changed.SubscriberItem>,
    SubscriberDataGrouping
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:lfm:mappingservice",
        "2015-09-06", "subscriber-item").intern();


}

==> mappingservice.api-1.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/lfm/mappingservice/rev150906/mapping/changed/SubscriberItem.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.mapping.changed;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.lisp.proto.rev151105.SubscriberDataGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.MappingChanged;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * The list of subscribers to be notified of this change.
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>odl-mappingservice</b>
 * <pre>
 * list subscriber-item {
 *   uses lisp-proto:subscriber-data-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>odl-mappingservice/mapping-changed/subscriber-item</i>
 *
 * <p>To create instances of this class use {@link SubscriberItemBuilder}.
 * @see SubscriberItemBuilder
 *
 *
 */
public interface SubscriberItem
    extends
    ChildOf<MappingChanged>,
    Augmentable<SubscriberItem>,
    SubscriberDataGrouping
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("subscriber-item");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.mapping.changed.SubscriberItem> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.mapping.changed.SubscriberItem.class;
    }

}
